@@ -4,13 +4,18 @@ from typing import Optional
 from servey.security.authorization import Authorization
 
 from persisty.factory.store_factory_abc import StoreFactoryABC
-from persisty.store.owned_store import OwnedStore
+from persisty.store.owned_store import OwnedStore, meta_with_non_editable_subject_id
 from persisty.store.store_abc import StoreABC
 from persisty.store_meta import T, StoreMeta
 
 
 @dataclass
 class OwnedStoreFactory(StoreFactoryABC[T]):
+    """
+    Factory for stores where ownership of items is asserted by means of an attribute name. The value for the
+    attribute is set from the Authorization subject_id, and special permission may be required for update / delete
+    operations
+    """
     store_factory: StoreFactoryABC[T]
     subject_id_attr_name: str = "subject_id"
     require_ownership_for_read: bool = False
@@ -18,7 +23,11 @@ class OwnedStoreFactory(StoreFactoryABC[T]):
     require_ownership_for_delete: bool = True
 
     def get_meta(self) -> StoreMeta:
-        return self.store_factory.get_meta()
+        meta = getattr(self, '_meta', None)
+        if meta is None:
+            meta = meta_with_non_editable_subject_id(self.store_factory.get_meta(), self.subject_id_attr_name)
+            setattr(self, '_meta', meta)
+        return meta
 
     def create(self, authorization: Optional[Authorization]) -> Optional[StoreABC[T]]:
         store = self.store_factory.create(authorization)
